==> devebot-cli-0.2.1.tgz: package/lib/utils/textui.js <==
'use strict';

var lodash = require('lodash');
var util = require('util');
var Table = require('cli-table2');
var Validator = require('jsonschema').Validator;
var validator = new Validator();

var clientInfo = require('./appinfo.js');
var constx = require('./constx.js');

function TextUI(a) {
  a = a || {};

  var b = {
    style: {
      head: [] //disable colors in header cells
      , border: [] //disable colors for the border
    }
  };

  this.displayCliHeader = function (a) {
    a = a || {};
    var b = a.appinfo;
    console.log('%s: %s (v%s)', clientInfo.name, clientInfo.description, clientInfo.version);
    if (lodash.isObject(b)) {
      console.log('%s: %s (v%s)', b.name, b.description, b.version);
    }
  };

  this.displayCliFooter = function (b) {
    var c = a.config;
    var d = a.myperf;

    var e = [];

    if (lodash.isObject(c)) {
      var f = c.getContext();
      e.push(lodash.isEmpty(f) ? 'default' : f);
      var g = c.getConfig();
      if (lodash.isObject(g)) {
        e.push(util.format(' - %s://%s:%s%s', g.protocol || 'http', g.host, g.port, g.path));
      }
    }

    if (lodash.isObject(d)) {
      var h = d.stop();
      e.push('\n', util.format('Time: %s - Memory: %s', h.time_text, h.memory_text));
    }

    ["", "------------------------------------------------------------------------------------", e.join(''), ""].forEach(function (a) {
      console.log(a);
    });
  };

  this.displayCliOutput = function (a) {
    a = a || {};
    var b = validator.validate(a, constx.argumentSchema);
    if (b.errors.length > 0) {
      c(a);
    } else {
      var e = {};
      e.isError = a.state == 'failed';
      var f = a.details || [];
      if (!lodash.isArray(f)) f = [f];
      f.forEach(function (a) {
        d(a, e);
      });
    }
  };

  var c = function renderInvalid(a) {
    var c = new Table(lodash.assign(b, {
      head: ['Invalid output format. Render full result object in JSON format'],
      colWidths: [78]
    }));
    c.push([JSON.stringify(a, null, 2)]);

    console.log('');
    console.log(c.toString());
  };

  var d = function renderBlock(a, b) {
    i(a, b);

    switch (a.type) {
      case 'record':
      case 'object':
        e(a);
        break;
      case 'table':
      case 'grid':
        f(a);
        break;
      case 'json':
        g(a);
        break;
      default:
        h(a);
        break;
    }
  };

  var e = function renderRecord(a) {
    var c = a.label;
    var d = a.data;
    var e = Object.keys(d);
    var f = [];
    e.forEach(function (a) {
      if (c[a]) {
        var b = {};
        b[c[a]] = d[a];
        f.push(b);
      }
    });

    var g = new Table(lodash.assign(b, {}));
    f.forEach(function (a) {
      g.push(a);
    });

    console.log(g.toString());
  };

  var f = function renderTable(a) {
    var c = a.label;
    var d = Object.keys(c);

    var e = [];
    d.forEach(function (a) {
      e.push(c[a]);
    });

    var f = a.data;
    var g = [];
    f.forEach(function (a) {
      var b = [];
      for (var c = 0; c < d.length; c++) {
        b.push(a[d[c]]);
      }
      g.push(b);
    });

    var h = new Table(lodash.assign(b, {
      head: e
    }));

    g.forEach(function (a) {
      h.push(a);
    });

    console.log(h.toString());
  };

  var g = function renderJson(a) {
    var c = new Table(lodash.assign(b, {
      head: ['JSON'],
      colWidths: [78]
    }));
    c.push([JSON.stringify(a.data, null, 2)]);
    console.log(c.toString());
  };

  var h = function renderUnknown(a) {
    var c = new Table(lodash.assign(b, {
      head: ['Unknown result type'],
      colWidths: [78]
    }));
    c.push([JSON.stringify(a.data, null, 2)]);
    console.log(c.toString());
  };

  var i = function printTitle(a, b) {
    if (lodash.isString(a.title)) {
      console.log('');
      var c = b && b.isError ? '[x]' : '[v]';
      console.log('%s %s', c, a.title);
    }
  };

  this.displayException = function (a) {
    ["", "Command has been broken - " + a, "------------------------------------------------------------------------------------", "For more information about using this application, please see the guide:", "" + clientInfo.homepage, ""].forEach(function (a) {
      console.log(a);
    });
  };
}

module.exports = TextUI;

==> devebot-cli-0.2.2.tgz: package/lib/utils/textui.js <==
'use strict';

var lodash = require('lodash');
var util = require('util');
var Table = require('cli-table2');
var Validator = require('jsonschema').Validator;
var validator = new Validator();

var clientInfo = require('./appinfo.js');
var constx = require('./constx.js');

function TextUI(a) {
  a = a || {};

  var b = {
    style: {
      head: [] //disable colors in header cells
      , border: [] //disable colors for the border
    }
  };

  this.displayCliHeader = function (a) {
    a = a || {};
    var b = a.appinfo;
    console.log('Client[%s]: %s (v%s)', clientInfo.name, clientInfo.description, clientInfo.version);
    if (lodash.isObject(b) && b.name != clientInfo.name) {
      console.log('Server[%s]: %s (v%s)', b.name, b.description, b.version);
    }
  };

  this.displayCliFooter = function (b) {
    var c = a.config;
    var d = a.myperf;

    var e = [];

    if (lodash.isObject(c)) {
      var f = c.getContext();
      e.push(lodash.isEmpty(f) ? 'default' : f);
      var g = c.getConfig();
      if (lodash.isObject(g)) {
        e.push(util.format(' - %s://%s:%s%s', g.protocol || 'http', g.host, g.port, g.path));
      }
    }

    if (lodash.isObject(d)) {
      var h = d.stop();
      e.push('\n', util.format('Time: %s - Memory: %s', h.time_text, h.memory_text));
    }

    ["", "------------------------------------------------------------------------------------", e.join(''), ""].forEach(function (a) {
      console.log(a);
    });
  };

  this.displayCliOutput = function (a) {
    a = a || {};
    var b = validator.validate(a, constx.argumentSchema);
    if (b.errors.length > 0) {
      c(a);
    } else {
      var e = {};
      e.isError = a.state == 'failed';
      var f = a.payload || [];
      if (!lodash.isArray(f)) f = [f];
      f.forEach(function (a) {
        d(a, e);
      });
    }
  };

  var c = function renderInvalid(a) {
    var c = new Table(lodash.assign(b, {
      head: ['Invalid output format. Render full result object in JSON format'],
      colWidths: [78]
    }));
    c.push([JSON.stringify(a, null, 2)]);

    console.log('');
    console.log(c.toString());
  };

  var d = function renderBlock(a, b) {
    i(a, b);

    switch (a.type) {
      case 'record':
      case 'object':
        e(a);
        break;
      case 'table':
      case 'grid':
        f(a);
        break;
      case 'json':
        g(a);
        break;
      default:
        h(a);
        break;
    }
  };

  var e = function renderRecord(a) {
    var c = a.label;
    var d = a.data;
    var e = Object.keys(d);
    var f = [];
    e.forEach(function (a) {
      if (c[a]) {
        var b = {};
        b[c[a]] = d[a];
        f.push(b);
      }
    });

    var g = new Table(lodash.assign(b, {}));
    f.forEach(function (a) {
      g.push(a);
    });

    console.log(g.toString());
  };

  var f = function renderTable(a) {
    var c = a.label;
    var d = Object.keys(c);

    var e = [];
    d.forEach(function (a) {
      e.push(c[a]);
    });

    var f = a.data;
    var g = [];
    f.forEach(function (a) {
      var b = [];
      for (var c = 0; c < d.length; c++) {
        b.push(a[d[c]]);
      }
      g.push(b);
    });

    var h = new Table(lodash.assign(b, {
      head: e
    }));

    g.forEach(function (a) {
      h.push(a);
    });

    console.log(h.toString());
  };

  var g = function renderJson(a) {
    var c = new Table(lodash.assign(b, {
      head: ['JSON'],
      colWidths: [78]
    }));
    c.push([JSON.stringify(a.data, null, 2)]);
    console.log(c.toString());
  };

  var h = function renderUnknown(a) {
    var c = new Table(lodash.assign(b, {
      head: ['Unknown result type'],
      colWidths: [78]
    }));
    c.push([JSON.stringify(a.data, null, 2)]);
    console.log(c.toString());
  };

  var i = function printTitle(a, b) {
    if (lodash.isString(a.title)) {
      console.log('');
      var c = b && b.isError ? '[x]' : '[v]';
      console.log('%s %s', c, a.title);
    }
  };

  this.displayException = function (a) {
    ["", "Command has been broken - " + a, "------------------------------------------------------------------------------------", "For more information about using this application, please see the guide:", "" + clientInfo.homepage, ""].forEach(function (a) {
      console.log(a);
    });
  };
}

module.exports = TextUI;
